extern const char **_dictionary_treemenu;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_treemenu;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_treemenu("treemenu",_dictionary_treemenu,20,3);\
	void dummy_dict_treemenu(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_treemenu[id]
	#define MSG_B(id,m,n)	_dictionary_treemenu[id]
	#define MSG_R(id)	_dictionary_treemenu[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_treemenu,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_treemenu,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_treemenu,id)
#endif
#define T_USAGE	0
#define B_QUIT	1
#define B_ACTIVATE	2
#define N_NOJOB	3
#define B_HELP	4
#define M_ABOUT	5
#define M_INTRO	6
#define M_TOPIC	7
#define B_FASTQUIT	8
#define M_COMMANDLINE	9
#define T_ABOUT	10
#define A_ABOUT1	11
#define A_ABOUT3	12
#define M_STATUS	13
#define I_VARIOUS	14
#define M_FILE	15
#define I_PROFILE	16
#define T_MODTREEMENU	17
#define I_TEXTMODE	18
#define I_GUIMODE	19
